hpgeom modules
==============

.. toctree::
    :maxdepth: 4

hpgeom
------
.. automodule:: hpgeom.hpgeom
    :members:
    :special-members:
    :show-inheritance:

healpy compatibility
--------------------
.. automodule:: hpgeom.healpy_compat
    :members:
    :special-members:
    :show-inheritance:
